@@ -35,7 +35,9 @@ class EngineHandler(WSGIHandler, EventEmitter):
     def bind_framework_info(self, socket):
         # Run framework's wsgi application to hook up framework specific info eg. request
         # This is why we define /socket.io url in web frameworks and points them to a view
+        logger.debug("[EngineHandler] Bind the framework specific info to engine socket")
         self.environ['engine_socket'] = socket
+
         try:
             start_response = lambda status, headers, exc=None: None
             self.application(self.environ, start_response)
@@ -62,18 +64,26 @@ class EngineHandler(WSGIHandler, EventEmitter):
         setattr(request, 'handler', self)
         setattr(request, 'response', Response())
 
+        logger.debug("[EngineHandler] Incoming request with %s" % request.GET)
+
         # Upgrade the websocket if needed
         is_websocket = False
-        if 'Upgrade' in request.headers:
-            # This is the ws upgrade request, here we handles the upgrade
-            ws_handler = self.server_context.ws_handler_class(self.socket, self.client_address, self.server)
-            ws_handler.__dict__.update(self.__dict__)
-            ws_handler.prevent_wsgi_call = True
-            ws_handler.handle_one_response()
-            # Suppose here we have an websocket connection
-            setattr(request, 'websocket', ws_handler.websocket)
+        if request.GET.get("transport", None) == "websocket":
+            if 'Upgrade' in request.headers:
+                logger.debug("[EngineHandler] It is a websocket upgrade request")
+                # This is the ws upgrade request, here we handles the upgrade
+                ws_handler = self.server_context.ws_handler_class(self.socket, self.client_address, self.server)
+                ws_handler.__dict__.update(self.__dict__)
+                ws_handler.prevent_wsgi_call = True
+                ws_handler.handle_one_response()
+                # Suppose here we have an websocket connection
+                setattr(request, 'websocket', ws_handler.websocket)
 
-            is_websocket = True
+                is_websocket = True
+
+            else:
+                logger.warning("[EngineHandler] Client fired a websocket but the 'Upgrade' Header loose somewhere, maybe your proxy")
+                return
 
         sid = request.GET.get("sid", None)
         b64 = request.GET.get("b64", False)
@@ -84,23 +94,28 @@ class EngineHandler(WSGIHandler, EventEmitter):
         if socket and not is_websocket:
             # We spawn a new gevent here, let socket do its own business.
             # In current event loop, we will wait on request.response, which is set in socket.set_request
-            gevent.spawn(socket.process_request, request)
+            logger.debug("[EngineHandler] Found existing socket")
             self.bind_framework_info(socket)
+            gevent.spawn(socket.process_request, request)
 
         else:
             if socket is None:
+                logger.debug("[EngineHandler] No existing socket, handshake")
                 socket = self._do_handshake(b64=b64, request=request)
 
                 if not is_websocket:
+                    logger.debug("[EngineHandler] The incoming request not websocket, bind framework info")
                     self.bind_framework_info(socket)
 
             if is_websocket and socket.transport.name != 'websocket':
+                logger.debug("[EngineHandler] websocket, proceed as upgrade")
                 # Here we have a upgrade
                 ws_transport = WebsocketTransport(self, {})
                 ws_transport.process_request(request)
                 socket.maybe_upgrade(ws_transport)
 
         # wait till the response ends
+        logger.debug("[EngineHandler] Waiting for the response signal")
         request.response.join()
 
         # The response object can be used as a wsgi application which will send out the buffer
